<?php
/**
 * Recommends plugins for use with the theme via the TGMA Script
 *
 * @package Amiy WordPress theme
 */

function amiy_tgmpa_plugins_register() {

	// Get array of recommended plugins.
    $theme_required_plugin_lists = array();
    $url = 'https://api.wordpress.org/plugins/info/1.0/unyson';
    $api_response = wp_remote_get( $url );

    if ( is_array( $api_response ) && ! is_wp_error( $api_response ) ) {
        if( isset($api_response['response']) && !empty($api_response['response']) ) {
            if ( 404 == $api_response['response']['code'] && 'Not Found' == $api_response['response']['message'] ) {
                $unyson_plugin = array(
                    array(
                        'name'               => esc_html__('Unyson', 'amiy'),
                        'slug'               => 'unyson',
                        'source'             => AMIY_MODULE_DIR . '/plugins/unyson.zip',
                        'required'           => true,
                        'version'            => '2.7.28',
                        'force_activation'   => false,
                        'force_deactivation' => false,
                    )
                );
            } else {
                $unyson_plugin = array(
                    array(
                        'name'     => esc_html__('Unyson', 'amiy'),
                        'slug'     => 'unyson',
                        'required' => true,
                    )
                );
            }
        }
    }

	$plugins_list = array(
        array(
            'name'               => esc_html__('Amiy Plus', 'amiy'),
            'slug'               => 'amiy-plus',
            'source'             => AMIY_MODULE_DIR . '/plugins/amiy-plus.zip',
            'required'           => true,
            'version'            => '1.0.0',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'               => esc_html__('Amiy Pro', 'amiy'),
            'slug'               => 'amiy-pro',
            'source'             => AMIY_MODULE_DIR . '/plugins/amiy-pro.zip',
            'required'           => true,
            'version'            => '1.0.1',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'     => esc_html__('Elementor', 'amiy'),
            'slug'     => 'elementor',
            'required' => true,
        ),
        array(
            'name'               => esc_html__('WeDesignTech Elementor Addon', 'amiy'),
            'slug'               => 'wedesigntech-elementor-addon',
            'source'             => AMIY_MODULE_DIR . '/plugins/wedesigntech-elementor-addon.zip',
            'required'           => true,
            'version'            => '1.0.1',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'               => esc_html__('WeDesignTech Store Locator', 'amiy'),
            'slug'               => 'wedesigntech-storelocator',
            'source'             => AMIY_MODULE_DIR . '/plugins/wedesigntech-storelocator.zip',
            'required'           => true,
            'version'            => '1.0.0',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'               => esc_html__('WeDesignTech Ultimate Booking Addon', 'amiy'),
            'slug'               => 'wedesigntech-ultimate-booking-addon',
            'source'             => AMIY_MODULE_DIR . '/plugins/wedesigntech-ultimate-booking-addon.zip',
            'required'           => true,
            'version'            => '1.0.0',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'     => esc_html__('WooCommerce', 'amiy'),
            'slug'     => 'woocommerce',
            'required' => true,
        ),
        array(
            'name'               => esc_html__('Amiy Shop', 'amiy'),
            'slug'               => 'amiy-shop',
            'source'             => AMIY_MODULE_DIR . '/plugins/amiy-shop.zip',
            'required'           => true,
            'version'            => '1.0.0',
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'     => esc_html__('Variation Swatches for WooCommerce', 'amiy'),
            'slug'     => 'woo-variation-swatches',
            'required' => true,
        ),
        array(
            'name'     => esc_html__('TI WooCommerce Wishlist', 'amiy'),
            'slug'     => 'ti-woocommerce-wishlist',
            'required' => true,
        ),
        array(
            'name'     => esc_html__('YITH WooCommerce Quick View', 'amiybeauty'),
            'slug'     => 'yith-woocommerce-quick-view',
            'required' => true,
        ),
        array(
            'name'     => esc_html__('YITH WooCommerce Gift Cards', 'amiybeauty'),
            'slug'     => 'yith-woocommerce-gift-cards',
            'required' => true,
        ),
        array(
            'name'     => esc_html__('Contact Form 7', 'amiy'),
            'slug'     => 'contact-form-7',
            'required' => true,
        )
	);

    $theme_required_plugin_lists = array_merge( $unyson_plugin, $plugins_list );
    $plugins = apply_filters('amiy_required_plugins_list', $theme_required_plugin_lists);

	// Register notice
	tgmpa( $plugins, array(
		'id'           => 'amiy_theme',
		'domain'       => 'amiy',
		'menu'         => 'install-required-plugins',
		'has_notices'  => true,
		'is_automatic' => true,
		'dismissable'  => true,
	) );

}
add_action( 'tgmpa_register', 'amiy_tgmpa_plugins_register' );